@@ -1,6 +1,6 @@
 use v6;
 
-unit module TAP:ver<0.0.9>;
+unit module TAP:ver<0.2.0>;
 
 role Entry {
     has Str:D $.raw is required handles <Str>;
@@ -101,7 +101,7 @@ class Result {
         $!exit-status.defined ?? $!exit-status.exitcode !! Int;
     }
     method wait() {
-        $!exit-status.defined ?? $!exit-status.status !! Int;
+        $!exit-status.defined ?? ($!exit-status.exitcode +< 8) +| $!exit-status.signal !! Int;
     }
 
     method has-problems($ignore-exit) {
@@ -877,7 +877,7 @@ class Harness {
             TAP::Source::Proc.new(:$name, :$!path, :args[ |@!args, $name ], :$err);
         }
     }
-    class SourceHandler::Perl6 does SourceHandler::Proc {
+    class SourceHandler::Raku does SourceHandler::Proc {
         submethod BUILD(:@incdirs, Str:D :$!path = $*EXECUTABLE.absolute) {
             @!args = @incdirs.map("-I" ~ *);
         }
@@ -885,6 +885,9 @@ class Harness {
             0.5;
         }
     }
+    class SourceHandler::Perl6 is SourceHandler::Raku {
+        # This may later give deprecation warnings
+    }
     class SourceHandler::Exec does SourceHandler::Proc {
         method new (*@ ($path, *@args)) {
             self.bless(:$path, :@args);
@@ -894,11 +897,19 @@ class Harness {
         }
     }
 
-    has SourceHandler @.handlers = SourceHandler::Perl6.new();
+    my sub load-reporter(Str $name --> Reporter) {
+        my $classname = $name.subst('-', '::', :g);
+        my $loaded = try ::($classname);
+        return $loaded if $loaded !eqv Any;
+        require ::($classname);
+        return ::($classname);
+    }
+
+    has SourceHandler @.handlers = SourceHandler::Raku.new();
     has IO::Handle $.handle = $*OUT;
     has Formatter::Volume $.volume = ?%*ENV<HARNESS_VERBOSE> ?? Verbose !! Normal;
-    has TAP::Reporter:U $.reporter-class = $!handle.t && $!volume < Verbose ?? TAP::Reporter::Console !! TAP::Reporter::Text;
     has Str %!env-options = (%*ENV<HARNESS_OPTIONS> // '').split(':').grep(*.chars).map: { / ^ (.) (.*) $ /; ~$0 => val(~$1) };
+    has TAP::Reporter:U $.reporter-class = %!env-options<r> ?? load-reporter(%!env-options<r>) !! $!handle.t && $!volume < Verbose ?? TAP::Reporter::Console !! TAP::Reporter::Text;
     has Int:D $.jobs = %!env-options<j> // 1;
     has Bool:D $.timer = ?%*ENV<HARNESS_TIMER>;
     subset ErrValue where any(IO::Handle:D, Supply, 'stderr', 'ignore', 'merge');
